import pystan
import matplotlib.pyplot as plt
import numpy as np


RawData = [[1,  1, 0, 0, 1, 0, 0],
           [1,  1, 0, 0, 0, 1, 0],
           [10, 1, 0, 0, 0, 0, 1],
           [3,  0, 1, 0, 1, 0, 0],
           [2,  0, 1, 0, 0, 1, 0],
           [10, 0, 1, 0, 0, 0, 1],
           [6,  0, 0, 1, 1, 0, 0],
           [2,  0, 0, 1, 0, 1, 0],
           [4,  0, 0, 1, 0, 0, 1]]

F = []
Xr1 = []
Xr2 = []
Xr3 = []
Xc1 = []
Xc2 = []
Xc3 = []
for v in RawData:
    F.append(v[0])
    Xr1.append(v[1])
    Xr2.append(v[2])
    Xr3.append(v[3])
    Xc1.append(v[4])
    Xc2.append(v[5])
    Xc3.append(v[6])

for i in range(9):
    print(' ', F[i], '  ', Xr1[i], '  ', Xr2[i], '  ', Xr3[i],
          '  ', Xc1[i], '  ', Xc2[i], '  ', Xc3[i])

N = 9
Data = {'N': N, 'F': F, 'Xr1': Xr1, 'Xr2': Xr2, 'Xr3': Xr3,
        'Xc1': Xc1, 'Xc2': Xc2, 'Xc3': Xc3}

sm = pystan.StanModel(file = 'Poisson.stan')
fit = sm.sampling(data = Data,
                  pars = ['mu', 'a2', 'a3', 'b2', 'b3',
                          'g22', 'g23', 'g32', 'g33'], n_jobs = 1)
print(fit)
f = open('Results.txt', 'w')
f.write('fit = \n{}\n'.format(fit))

a3 = fit['a3']
cnt_a3_pos = (a3 > 0.0).sum()
print('\nP(a3 > 0.0) = {0:.3f}'.format(cnt_a3_pos / len(a3)))
f.write('\nP(a3 > 0.0) = {0:.3f}\n'.format(cnt_a3_pos / len(a3)))


b3 = fit['b3']
cnt_b3_pos = (b3 > 0.0).sum()
print('P(b3 > 0.0) = {0:.3f}'.format(cnt_b3_pos / len(b3)))
f.write('\nP(b3 > 0.0) = {0:.3f}\n'.format(cnt_b3_pos / len(b3)))

g33 = fit['g33']
cnt_g33_neg = (g33 < 0.0).sum()
print('P(g33 < 0.0) = {0:.3f}'.format(cnt_g33_neg / len(g33)))
f.write('\nP(g33 < 0.0) = {0:.3f}\n'.format(cnt_g33_neg / len(g33)))

f.close()


